@@ -1,6 +1,6 @@
-from simulator.stats import Stats
-from simulator.skills.skill_modifier import SkillModifier
-from simulator.timeline_builders.rotation_builder import RotationBuilder
+from ama_xiv_combat_sim.simulator.stats import Stats
+from ama_xiv_combat_sim.simulator.skills.skill_modifier import SkillModifier
+from ama_xiv_combat_sim.simulator.timeline_builders.rotation_builder import RotationBuilder
 
 
 def get_rotation_AST(skill_library):
