@@ -1,17 +1,17 @@
-from simulator.calcs.damage_class import DamageClass
-from simulator.calcs.forced_crit_or_dh import ForcedCritOrDH
-from simulator.game_data.patch_70.convenience_timings import (
+from ama_xiv_combat_sim.simulator.calcs.damage_class import DamageClass
+from ama_xiv_combat_sim.simulator.calcs.forced_crit_or_dh import ForcedCritOrDH
+from ama_xiv_combat_sim.simulator.game_data.patch_70.convenience_timings import (
     get_auto_timing,
     get_instant_timing_spec,
 )
-from simulator.sim_consts import SimConsts
-from simulator.skills.skill import Skill
-from simulator.specs.damage_spec import DamageSpec
-from simulator.specs.follow_up import FollowUp
-from simulator.specs.job_resource_settings import JobResourceSettings
-from simulator.specs.job_resource_spec import JobResourceSpec
-from simulator.specs.status_effect_spec import StatusEffectSpec
-from simulator.specs.timing_spec import TimingSpec
+from ama_xiv_combat_sim.simulator.sim_consts import SimConsts
+from ama_xiv_combat_sim.simulator.skills.skill import Skill
+from ama_xiv_combat_sim.simulator.specs.damage_spec import DamageSpec
+from ama_xiv_combat_sim.simulator.specs.follow_up import FollowUp
+from ama_xiv_combat_sim.simulator.specs.job_resource_settings import JobResourceSettings
+from ama_xiv_combat_sim.simulator.specs.job_resource_spec import JobResourceSpec
+from ama_xiv_combat_sim.simulator.specs.status_effect_spec import StatusEffectSpec
+from ama_xiv_combat_sim.simulator.specs.timing_spec import TimingSpec
 
 
 def add_mnk_skills(skill_library):
@@ -124,6 +124,7 @@ def add_mnk_skills(skill_library):
                     "Rockbreaker",
                     "Four-point Fury",
                     "Elixir Burst",
+                    "Leaping Opo",
                     "Fire's Reply",
                 ),
             ),
@@ -250,7 +251,10 @@ def add_mnk_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1290, gcd_base_recast_time=2000
             ),
-            follow_up_skills=(opo_opo_fury_follow_up,),
+            follow_up_skills={SimConsts.DEFAULT_CONDITION: tuple(),
+                              'Opo-opo Form': (opo_opo_fury_follow_up,),
+                              'Formless Fist': (opo_opo_fury_follow_up,),
+                              'Opo-opo Form, Formless Fist': (opo_opo_fury_follow_up,)}
         )
     )
     skill_library.add_skill(
@@ -447,6 +451,7 @@ def add_mnk_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=760, gcd_base_recast_time=2000
             ),
+            follow_up_skills = (opo_opo_form_follow_up,)
         )
     )
     skill_library.add_skill(
@@ -487,6 +492,7 @@ def add_mnk_skills(skill_library):
             name="Perfect Balance",
             is_GCD=False,
             timing_spec=instant_timing_spec,  # Does apply instantly it seems.
+            #fix this- PB charges can be eaten by non-opo skills too.
             follow_up_skills=(
                 opo_opo_form_follow_up,
                 opo_opo_form_follow_up,
