@@ -1,15 +1,15 @@
-from simulator.calcs.damage_class import DamageClass
-from simulator.game_data.patch_70.convenience_timings import (
+from ama_xiv_combat_sim.simulator.calcs.damage_class import DamageClass
+from ama_xiv_combat_sim.simulator.game_data.patch_70.convenience_timings import (
     get_auto_timing,
     get_instant_timing_spec,
 )
-from simulator.sim_consts import SimConsts
-from simulator.skills.skill import Skill
-from simulator.specs.combo_spec import ComboSpec
-from simulator.specs.damage_spec import DamageSpec
-from simulator.specs.follow_up import FollowUp
-from simulator.specs.status_effect_spec import StatusEffectSpec
-from simulator.specs.timing_spec import TimingSpec
+from ama_xiv_combat_sim.simulator.sim_consts import SimConsts
+from ama_xiv_combat_sim.simulator.skills.skill import Skill
+from ama_xiv_combat_sim.simulator.specs.combo_spec import ComboSpec
+from ama_xiv_combat_sim.simulator.specs.damage_spec import DamageSpec
+from ama_xiv_combat_sim.simulator.specs.follow_up import FollowUp
+from ama_xiv_combat_sim.simulator.specs.status_effect_spec import StatusEffectSpec
+from ama_xiv_combat_sim.simulator.specs.timing_spec import TimingSpec
 
 
 def add_rpr_skills(skill_library):
@@ -193,7 +193,11 @@ def add_rpr_skills(skill_library):
             is_GCD=True,
             damage_spec=DamageSpec(potency=460),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=1030
+                base_cast_time=0,
+                animation_lock=650,
+                application_delay=1030,
+                affected_by_haste_buffs=False,
+                affected_by_speed_stat=False,
             ),
         )
     )
@@ -203,7 +207,11 @@ def add_rpr_skills(skill_library):
             is_GCD=True,
             damage_spec=DamageSpec(potency=180),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=670
+                base_cast_time=0,
+                animation_lock=650,
+                application_delay=670,
+                affected_by_haste_buffs=False,
+                affected_by_speed_stat=False,
             ),
         )
     )
@@ -215,7 +223,7 @@ def add_rpr_skills(skill_library):
             add_to_skill_modifier_condition=True,
             num_uses=1,
             duration=60 * 1000,
-            skill_allowlist=("Gibbet","Executioner's Gibbet"),
+            skill_allowlist=("Gibbet", "Executioner's Gibbet"),
         ),
     )
     enhanced_gibbet_follow_up = FollowUp(
@@ -228,7 +236,7 @@ def add_rpr_skills(skill_library):
             add_to_skill_modifier_condition=True,
             num_uses=1,
             duration=60 * 1000,
-            skill_allowlist=("Gallows","Executioner's Gallows"),
+            skill_allowlist=("Gallows", "Executioner's Gallows"),
         ),
     )
     enhanced_gallows_follow_up = FollowUp(
@@ -352,7 +360,11 @@ def add_rpr_skills(skill_library):
                 "Enhanced Void Reaping": DamageSpec(potency=560),
             },
             timing_spec=TimingSpec(
-                base_cast_time=0, gcd_base_recast_time=1500, application_delay=540
+                base_cast_time=0,
+                gcd_base_recast_time=1500,
+                application_delay=540,
+                affected_by_haste_buffs=False,
+                affected_by_speed_stat=False,
             ),
             follow_up_skills=(enhanced_cross_reaping_follow_up,),
         )
@@ -497,7 +509,7 @@ def add_rpr_skills(skill_library):
             ),
         )
     )
-        
+
     skill_library.add_skill(
         Skill(
             name="Hell's Ingress",
@@ -516,7 +528,7 @@ def add_rpr_skills(skill_library):
             ),
         )
     )
-        
+
     skill_library.add_skill(
         Skill(
             name="Hell's Egress",
