@@ -1,16 +1,16 @@
-from simulator.calcs.damage_class import DamageClass
-from simulator.calcs.forced_crit_or_dh import ForcedCritOrDH
-from simulator.game_data.patch_70.convenience_timings import (
+from ama_xiv_combat_sim.simulator.calcs.damage_class import DamageClass
+from ama_xiv_combat_sim.simulator.calcs.forced_crit_or_dh import ForcedCritOrDH
+from ama_xiv_combat_sim.simulator.game_data.patch_70.convenience_timings import (
     get_auto_timing,
     get_instant_timing_spec,
 )
-from simulator.sim_consts import SimConsts
-from simulator.skills.skill import Skill
-from simulator.specs.combo_spec import ComboSpec
-from simulator.specs.damage_spec import DamageSpec
-from simulator.specs.follow_up import FollowUp
-from simulator.specs.status_effect_spec import StatusEffectSpec
-from simulator.specs.timing_spec import TimingSpec
+from ama_xiv_combat_sim.simulator.sim_consts import SimConsts
+from ama_xiv_combat_sim.simulator.skills.skill import Skill
+from ama_xiv_combat_sim.simulator.specs.combo_spec import ComboSpec
+from ama_xiv_combat_sim.simulator.specs.damage_spec import DamageSpec
+from ama_xiv_combat_sim.simulator.specs.follow_up import FollowUp
+from ama_xiv_combat_sim.simulator.specs.status_effect_spec import StatusEffectSpec
+from ama_xiv_combat_sim.simulator.specs.timing_spec import TimingSpec
 
 
 def add_sam_skills(skill_library):
