@@ -1,18 +1,18 @@
 import numpy as np
 
-from simulator.calcs.damage_class import DamageClass
-from simulator.game_data.patch_70.convenience_timings import (
+from ama_xiv_combat_sim.simulator.calcs.damage_class import DamageClass
+from ama_xiv_combat_sim.simulator.game_data.patch_70.convenience_timings import (
     get_shot_timing,
     get_instant_timing_spec,
 )
-from simulator.sim_consts import SimConsts
-from simulator.skills.skill import Skill
-from simulator.specs.damage_spec import DamageSpec
-from simulator.specs.follow_up import FollowUp
-from simulator.specs.job_resource_settings import JobResourceSettings
-from simulator.specs.job_resource_spec import JobResourceSpec
-from simulator.specs.status_effect_spec import StatusEffectSpec
-from simulator.specs.timing_spec import TimingSpec
+from ama_xiv_combat_sim.simulator.sim_consts import SimConsts
+from ama_xiv_combat_sim.simulator.skills.skill import Skill
+from ama_xiv_combat_sim.simulator.specs.damage_spec import DamageSpec
+from ama_xiv_combat_sim.simulator.specs.follow_up import FollowUp
+from ama_xiv_combat_sim.simulator.specs.job_resource_settings import JobResourceSettings
+from ama_xiv_combat_sim.simulator.specs.job_resource_spec import JobResourceSpec
+from ama_xiv_combat_sim.simulator.specs.status_effect_spec import StatusEffectSpec
+from ama_xiv_combat_sim.simulator.specs.timing_spec import TimingSpec
 
 
 def add_brd_skills(skill_library):
@@ -642,14 +642,14 @@ def add_brd_skills(skill_library):
         ),
         delay_after_parent_application=0,
     )
-    
+
     skill_library.add_skill(
         Skill(
             name="Radiant Finale",
             is_GCD=False,
             buff_spec={
                 SimConsts.DEFAULT_CONDITION: StatusEffectSpec(
-                    damage_mult=10.06, duration=int(19.97 * 1000), is_party_effect=True
+                    damage_mult=1.06, duration=int(19.97 * 1000), is_party_effect=True
                 ),
                 "1 Mage's Coda": StatusEffectSpec(
                     damage_mult=1.02, duration=int(19.97 * 1000), is_party_effect=True
@@ -810,5 +810,4 @@ def add_brd_skills(skill_library):
             },
         )
     )
-
     return skill_library
