@@ -1,12 +1,12 @@
 import numpy as np
 
-from simulator.damage_simulator import DamageSimulator
-from simulator.skills.create_skill_library import create_skill_library
-from simulator.skills.skill_modifier import SkillModifier
-from simulator.stats import Stats
-from simulator.testing.test_class import TestClass
-from simulator.timeline_builders.damage_builder import DamageBuilder
-from simulator.timeline_builders.rotation_builder import RotationBuilder
+from ama_xiv_combat_sim.simulator.damage_simulator import DamageSimulator
+from ama_xiv_combat_sim.simulator.skills.create_skill_library import create_skill_library
+from ama_xiv_combat_sim.simulator.skills.skill_modifier import SkillModifier
+from ama_xiv_combat_sim.simulator.stats import Stats
+from ama_xiv_combat_sim.simulator.testing.test_class import TestClass
+from ama_xiv_combat_sim.simulator.timeline_builders.damage_builder import DamageBuilder
+from ama_xiv_combat_sim.simulator.timeline_builders.rotation_builder import RotationBuilder
 
 
 class TestJobs(TestClass):
@@ -177,6 +177,49 @@ class TestJobs(TestClass):
         )
         return self.__test_skills(stats, skills_and_expected_damage)
 
+    @TestClass.is_a_test
+    def test_sch_aggregate_rotation(self):
+        stats = Stats(
+            wd=126,
+            weapon_delay=3.12,
+            main_stat=3366,
+            det_stat=1948,
+            crit_stat=2498,
+            dh_stat=688,
+            speed_stat=954,
+            job_class="SCH",
+            healer_or_caster_strength=351,
+            version="6.55",
+        )
+
+        rb = RotationBuilder(stats, self.__skill_library)
+        rb.add_next("Grade 8 Tincture")
+        rb.add_next("Broil IV")
+        rb.add_next("Biolysis")
+        rb.add_next("Broil IV")
+        rb.add_next("Broil IV")
+        rb.add_next("Chain Stratagem")
+        rb.add_next("Broil IV")
+        rb.add_next("Energy Drain")
+        rb.add_next("Broil IV")
+        rb.add_next("Energy Drain")
+        rb.add_next("Broil IV")
+        rb.add_next("Energy Drain")
+        rb.add_next("Broil IV")
+        rb.add_next("Broil IV")
+        rb.add_next("Energy Drain")
+        rb.add_next("Broil IV")
+        rb.add_next("Energy Drain")
+        rb.add_next("Broil IV")
+        rb.add_next("Energy Drain")
+        rb.add_next("Broil IV")
+        rb.add_next("Broil IV")
+        rb.add_next("Broil IV")
+        expected_damage = 292932.5
+        expected_total_time = 31200.0
+        return self.__test_aggregate_rotation(rb, expected_damage, expected_total_time)
+    
+
     @TestClass.is_a_test
     def test_ast_skills(self):
         stats = Stats(
@@ -1332,7 +1375,7 @@ class TestJobs(TestClass):
         rb.add_next("Gibbet")
 
         expected_damage = 493500.6
-        expected_total_time = 24200.0
+        expected_total_time = 24240.0
         return self.__test_aggregate_rotation(rb, expected_damage, expected_total_time)
 
     @TestClass.is_a_test
@@ -1440,6 +1483,40 @@ class TestJobs(TestClass):
         expected_total_time = 46920.0
         return self.__test_aggregate_rotation(rb, expected_damage, expected_total_time)
 
+    @TestClass.is_a_test
+    def test_smn_damage_instances(self):
+        stats = Stats(
+            wd=132,
+            weapon_delay=3.12,
+            main_stat=3379,
+            det_stat=1871,
+            crit_stat=2514,
+            dh_stat=1438,
+            speed_stat=502,
+            job_class="SMN",
+            version="7.0",
+        )
+
+        rb = RotationBuilder(
+            stats,
+            self.__skill_library,
+            enable_autos=False,
+            ignore_trailing_dots=True,
+            snap_dots_to_server_tick_starting_at=0,
+        )
+        rb.add_next("Ruin III")
+        rb.add_next("Aethercharge")
+        rb.add_next("Ruin III")
+        rb.add_next("Ruin III")
+        
+        expected = (
+            ("Ruin III", 19237.4),
+            ("Ruin III", 21928.8),
+            ("Ruin III", 19237.4),
+        )
+        return self.__test_rotation_damage(rb, expected)
+
+
     @TestClass.is_a_test
     def test_rdm_aggregate_rotation(self):
         stats = Stats(
@@ -1595,12 +1672,12 @@ class TestJobs(TestClass):
             self.__skill_library,
             ignore_trailing_dots=True,
             snap_dots_to_server_tick_starting_at=0,
-            fight_start_time=0
+            fight_start_time=0,
         )
 
         rb.add_next("Flare Star")
-        rb.add_next("Fire III")        
-        rb.add_next("Flare Star")        
+        rb.add_next("Fire III")
+        rb.add_next("Flare Star")
         rb.add_next("Fire IV")
         rb.add_next("Flare Star")
         rb.add_next("Fire IV")
@@ -1620,7 +1697,7 @@ class TestJobs(TestClass):
             ("Flare Star", 38411.7),
             ("Fire IV", 34029.0),
             ("Flare Star", 38426.4),
-            ("Paradox", 30526.3),    
+            ("Paradox", 30526.3),
             ("Fire IV", 34068.2),
             ("Xenoglossy", 53659.7),
             ("Fire III", 23889.8),
@@ -1630,3 +1707,194 @@ class TestJobs(TestClass):
         )
 
         return self.__test_rotation_damage(rb, expected)
+
+    @TestClass.is_a_test
+    def test_vpr_aggregate_rotation(self):
+        stats = Stats(
+            wd=132,
+            weapon_delay=2.64,
+            main_stat=3367,
+            det_stat=1736,
+            crit_stat=2587,
+            dh_stat=1494,
+            speed_stat=508,
+            job_class="VPR",
+            version="7.0",
+        )
+
+        rb = RotationBuilder(
+            stats,
+            self.__skill_library,
+            enable_autos=True,
+            ignore_trailing_dots=True,
+            snap_dots_to_server_tick_starting_at=0,
+        )
+        skill_seq = (
+            "Dreadwinder",
+            "Serpent's Ire",
+            "Grade 8 Tincture",
+            "Hunter's Coil",
+            "Twinfang Bite",
+            "Twinblood Bite",
+            "Swiftskin's Coil",
+            "Twinblood Bite",
+            "Twinfang Bite",
+            "Reawaken",
+            "First Generation",
+            "First Legacy",
+            "Second Generation",
+            "Second Legacy",
+            "Third Generation",
+            "Third Legacy",
+            "Fourth Generation",
+            "Fourth Legacy",
+            "Ouroboros",
+            "Dreadwinder",
+            "Swiftskin's Coil",
+            "Twinblood Bite",
+            "Twinfang Bite",
+            "Hunter's Coil",
+            "Twinfang Bite",
+            "Twinblood Bite",
+            "Uncoiled Fury",
+            "Uncoiled Twinfang",
+            "Uncoiled Twinblood",
+        )
+        for e in skill_seq:
+            rb.add_next(e)
+
+        expected_damage = 608896.2
+        expected_total_time = 28860.0
+
+        return self.__test_aggregate_rotation(rb, expected_damage, expected_total_time)
+
+    @TestClass.is_a_test
+    def test_vpr_rotation_damage_instances(self):
+        stats = Stats(
+            wd=132,
+            weapon_delay=2.64,
+            main_stat=3367,
+            det_stat=1736,
+            crit_stat=2587,
+            dh_stat=1494,
+            speed_stat=508,
+            job_class="VPR",
+            version="7.0",
+        )
+        rb = RotationBuilder(
+            stats,
+            self.__skill_library,
+            ignore_trailing_dots=True,
+            snap_dots_to_server_tick_starting_at=0,
+            fight_start_time=0,
+        )
+
+        rot_and_expected = (
+            ("Hindsting Strike", 14205.2),
+            ("Flanksbane Fang", 18245.3),
+            ("Hindsbane Fang", 18245.3),
+            ("Flanksting Strike", 18245.3),
+            ("Flanksting Strike", 14205.2),
+            ("Hindsting Strike", 18232.7),
+            ("Hindsting Strike", 14205.2),
+            #
+            ("Flanksbane Fang", 18239.9),
+            ("Hindsbane Fang", 18239.9),
+        )
+        for e in rot_and_expected:
+            rb.add_next(e[0])
+
+        return self.__test_rotation_damage(rb, rot_and_expected)
+
+    @TestClass.is_a_test
+    def test_pct_rotation_damage_instances(self):
+        stats = Stats(
+            wd=132,
+            weapon_delay=3.12,
+            main_stat=3379,
+            det_stat=1871,
+            crit_stat=2514,
+            dh_stat=1438,
+            speed_stat=502,
+            job_class="PCT",
+            version="7.0",
+        )
+        rb = RotationBuilder(
+            stats,
+            self.__skill_library,
+            ignore_trailing_dots=True,
+            snap_dots_to_server_tick_starting_at=0,
+            fight_start_time=0,
+        )
+
+        # TODO: fill these out. For now, just do the e2e. I am tired.
+        rot_and_expected = (
+            ("Fire in Red", 21411.3),
+            ("Rainbow Drip", 48173.9),
+        )
+        for e in rot_and_expected:
+            rb.add_next(e[0])
+
+        return self.__test_rotation_damage(rb, rot_and_expected)
+
+    @TestClass.is_a_test
+    def test_pct_aggregate_rotation(self):
+        stats = Stats(
+            wd=132,
+            weapon_delay=3.12,
+            main_stat=3379,
+            det_stat=1871,
+            crit_stat=2514,
+            dh_stat=1438,
+            speed_stat=502,
+            job_class="PCT",
+            version="7.0",
+        )
+        rb = RotationBuilder(
+            stats,
+            self.__skill_library,
+            ignore_trailing_dots=True,
+            snap_dots_to_server_tick_starting_at=0,
+        )
+
+        skill_seq = (
+            ("Rainbow Drip"),
+            ("Grade 8 Tincture"),
+            ("Holy in White"),
+            ("Pom Muse"),
+            ("Swiftcast"),
+            ("Wing Motif"),            
+            ("Striking Muse"),
+            ("Fire in Red"),
+            ("Starry Muse"),
+            ("Star Prism"),
+            ("Hammer Stamp"),
+            ("Winged Muse"),
+            ("Hammer Brush"),
+            ("Mog of the Ages"),
+            ("Polishing Hammer"),
+            ("Subtractive Palette"),
+            ("Stone in Yellow"),
+            ("Thunder in Magenta"),
+            ("Comet in Black"),
+            ("Claw Motif"),
+            ("Clawed Muse"),
+            ("Holy in White"),
+            ("Rainbow Drip"),
+            ("Blizzard in Cyan"),
+            ("Aero in Green"),
+            ("Water in Blue"),
+            ("Fire in Red"),
+            ("Maw Motif"),
+            ("Aero in Green"),
+            ("Fanged Muse"),
+            ("Water in Blue"),
+        )
+
+        for e in skill_seq:
+            rb.add_next(e)
+            
+        expected_damage = 1030746.5
+        expected_total_time = 54470.0
+
+        return self.__test_aggregate_rotation(rb, expected_damage, expected_total_time)
