@@ -2,17 +2,21 @@ import copy
 import heapq
 import math
 
-from simulator.calcs.stat_fns import StatFns
-from simulator.game_data.game_consts import GameConsts
-from simulator.skills.skill_modifier import SkillModifier
-from simulator.timeline_builders.snapshot_and_application_events import (
+from ama_xiv_combat_sim.simulator.calcs.stat_fns import StatFns
+from ama_xiv_combat_sim.simulator.game_data.game_consts import GameConsts
+from ama_xiv_combat_sim.simulator.skills.skill_modifier import SkillModifier
+from ama_xiv_combat_sim.simulator.timeline_builders.snapshot_and_application_events import (
     SnapshotAndApplicationEvents,
 )
-from simulator.trackers.combo_tracker import ComboTracker
-from simulator.trackers.job_resource_tracker import JobResourceTracker
-from simulator.trackers.status_effects import StatusEffects
-from simulator.trackers.status_effect_tracker import StatusEffectTracker
-from simulator.utils import Utils
+from ama_xiv_combat_sim.simulator.trackers.combo_tracker import ComboTracker
+from ama_xiv_combat_sim.simulator.trackers.job_resource_tracker import (
+    JobResourceTracker,
+)
+from ama_xiv_combat_sim.simulator.trackers.status_effects import StatusEffects
+from ama_xiv_combat_sim.simulator.trackers.status_effect_tracker import (
+    StatusEffectTracker,
+)
+from ama_xiv_combat_sim.simulator.utils import Utils
 
 
 class RotationBuilder:
@@ -26,7 +30,7 @@ class RotationBuilder:
         enable_autos=False,
         ignore_trailing_dots=False,
         fight_start_time=None,
-        downtime_windows=[],
+        downtime_windows=(),
     ):
         self.__stats = stats
         # snap_dots_to_server_tick_starting_at is in SECONDS
@@ -508,6 +512,10 @@ class RotationBuilder:
                     if timing_spec.affected_by_haste_buffs
                     else recast_time
                 )
+                # default (2500 ms, at the time of writing) gcd recasts are hard
+                # stopped by a particular recast time.
+                if timing_spec.gcd_base_recast_time == GameConsts.GCD_RECAST_TIME:
+                    recast_time = max(recast_time, GameConsts.MIN_GCD_RECAST_TIME)
 
                 next_gcd_time = curr_t + recast_time
 
@@ -678,8 +686,10 @@ class RotationBuilder:
             se_tracker.add_to_status_effects(t, skill, skill_modifier)
             job_resource_tracker.add_resource(t, skill, skill_modifier)
 
+        se_tracker.expire_status_effects(curr_t)
         curr_buffs_and_skill_modifier = se_tracker.compile_buffs(curr_t, skill)
         curr_debuffs_and_skill_modifier = se_tracker.compile_debuffs(curr_t, skill)
+
         return (
             curr_buffs_and_skill_modifier,
             curr_debuffs_and_skill_modifier,
