@@ -1,6 +1,6 @@
 import numpy as np
 
-from simulator.game_data.game_consts import GameConsts
+from ama_xiv_combat_sim.simulator.game_data.game_consts import GameConsts
 
 class DamageTracker():
   def __init__(self):
